@@ -469,7 +469,7 @@ extern void re_set_registers
              unsigned num_regs, regoff_t *starts, regoff_t *ends));
 
 /* 4.2 bsd compatibility.  */
-#ifndef FREEBSD
+#if !defined(FREEBSD) && !defined(IRIX)
 extern char *re_comp _RE_ARGS (( char *));
 extern int re_exec _RE_ARGS (( char *));
 #endif
