@@ -36,7 +36,11 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/param.h>
+
+#ifndef NO_MOUNT_H
 #include <sys/mount.h>
+#endif
+
 #include <sys/wait.h>
 #include <errno.h>
 #include <dirent.h>
@@ -161,7 +165,7 @@ extern int errno;
 #define CF_SAVED ".cfsaved"
 
 #define Verbose if (VERBOSE || DEBUG || D2) printf
-#define EditVerbose  if (EDITVERBOSE || DEBUG || D2) printf
+#define EditVerbose  if (EDITVERBOSE || DEBUG) printf
 #define Debug2  if (DEBUG || D2) printf
 #define Debug1  if (DEBUG || D1) printf
 #define Debug   if (DEBUG || D1 || D2) printf
@@ -296,6 +300,7 @@ enum fileattr
    cfcptype,
    cflntype,
    cfinclude,
+   cfdirlinks,
    cfbad
    };
 
@@ -451,6 +456,7 @@ enum editnames
    CommentLinesStarting,
    CommentToLineMatching,
    CommentNLines,
+   UnCommentNLines,
    ReplaceAll,
    With,
    SetLine,
@@ -588,6 +594,7 @@ struct TidyPattern
    char               *pattern;
    char               *classes;
    char               travlinks;
+   char               dirlinks;          /* k=keep, t=tidy */
    char               searchtype;        /* a, m, c time */
    struct TidyPattern *next;
    };
