@@ -237,9 +237,9 @@ while (!feof(fp))
    buffer[0] = '\0';
    fgets(buffer,bufsize,fp);
    LINENUMBER++;
-   class[0]=NULL;
-   variable[0]=NULL;
-   value[0]=NULL;
+   class[0]='\0';
+   variable[0]='\0';
+   value[0]='\0';
 
    if (strlen(buffer)== 0)
       {
@@ -248,7 +248,7 @@ while (!feof(fp))
 
    sscanf(buffer,"%[^.].%[^:]:%[^\n]",class,variable,value);
 
-   if (class[0] == NULL || variable[0] == NULL || value[0] == NULL)
+   if (class[0] == '\0' || variable[0] == '\0' || value[0] == '\0')
       {
       printf("cfengine:%s:%s - Bad resource\n",VRCFILE,buffer);
       FatalError("Bad resource");
@@ -341,6 +341,8 @@ CLASSBUFF[0] = '\0';
 LINKFROM[0] = '\0';
 TICKSPERDAY = 60*60*24;
 
+re_syntax_options |= RE_INTERVALS;
+
 strcpy(VINPUTFILE,"cfengine.conf");
 strcpy(VSETUIDLOG,LOGFILE);
 strcpy(VNFSTYPE,"nfs");
@@ -363,14 +365,14 @@ for (i = 1; i < argc; i++)
    {
    sp = argv[i];
 
-   while (*sp != NULL)
+   while (*sp != '\0')
       {
       while (*sp++ == ' ' && *sp != '\0') /* Skip to arg */
          {
          }
 
       cfargv[cfargc++] = sp-1;
-      *(sp-2) = NULL;           /* break the argv string */
+      *(sp-2) = '\0';           /* break the argv string */
 
       while (*sp++ != ' ' && *sp != '\0') /* Skip to white space */
          {
@@ -458,7 +460,7 @@ CheckTimeZone()
 
 { time_t tloc;
 
-if (VTIMEZONE[0] == NULL)
+if (VTIMEZONE[0] == '\0')
    {
    FatalError("Program does not define a timezone");
    }
@@ -506,7 +508,7 @@ CheckProcesses()
   struct Item *procdata = NULL;
   char *psopts = VPSOPTS[VSYSTEMHARDCLASS];
 
-Verbose("Processes:\n");
+Banner("cfengine: Checking Processes:");
 
 if (!LoadProcessTable(&procdata,psopts))
    {
@@ -535,7 +537,7 @@ for (pp = VPROCLIST; pp != NULL; pp=pp->next)
 
 GetNameInfo()
 
-{ int i,j, found = false;
+{ int i, found = false;
   char *sp,*sp2;
   time_t tloc;
 
@@ -545,12 +547,12 @@ if (uname(&VSYSNAME) == -1)
    FatalError("cfengine: uname couldn't get kernel name info!!\n");
    }
 
-for (sp = VSYSNAME.sysname; *sp != NULL; sp++)
+for (sp = VSYSNAME.sysname; *sp != '\0'; sp++)
    {
    *sp = ToLower(*sp);
    }
 
-for (sp = VSYSNAME.machine; *sp != NULL; sp++)
+for (sp = VSYSNAME.machine; *sp != '\0'; sp++)
    {
    *sp = ToLower(*sp);
    }
@@ -558,7 +560,7 @@ for (sp = VSYSNAME.machine; *sp != NULL; sp++)
 
 for (i = 0; i < clssattr; i++)
    {
-   if (CLASSATTRIBUTES[i][0] == NULL)
+   if (CLASSATTRIBUTES[i][0] == '\0')
       {
       break;
       }
@@ -613,7 +615,7 @@ AddClassToHeap(VBUFF);
 Verbose("Additional hard class defined as: %s\n",VBUFF);
 
 sprintf(VBUFF,"%s_%s",VSYSNAME.sysname,VSYSNAME.release);
-for (sp = VBUFF; *sp != NULL; sp++)
+for (sp = VBUFF; *sp != '\0'; sp++)
    {
    if (*sp == '.')
       {
@@ -625,7 +627,7 @@ AddClassToHeap(VBUFF);
 Verbose("Additional hard class defined as: %s\n",VBUFF);
 
 sprintf(VBUFF,"%s_%s",VSYSNAME.sysname,VSYSNAME.machine);
-for (sp = VBUFF; *sp != NULL; sp++)
+for (sp = VBUFF; *sp != '\0'; sp++)
    {
    if (*sp == '.')
       {
@@ -637,7 +639,7 @@ AddClassToHeap(VBUFF);
 Verbose("Additional hard class defined as: %s\n",VBUFF);
 
 sprintf(VBUFF,"%s_%s_%s",VSYSNAME.sysname,VSYSNAME.machine,VSYSNAME.release);
-for (sp = VBUFF; *sp != NULL; sp++)
+for (sp = VBUFF; *sp != '\0'; sp++)
    {
    if (*sp == '.')
       {
@@ -649,7 +651,7 @@ AddClassToHeap(VBUFF);
 Verbose("Additional hard class defined as: %s\n",VBUFF);
 
 sprintf(VBUFF,"%s_%s_%s_%s",VSYSNAME.sysname,VSYSNAME.machine,VSYSNAME.release,VSYSNAME.version);
-for (sp = VBUFF; *sp != NULL; sp++)
+for (sp = VBUFF; *sp != '\0'; sp++)
    {
    if (*sp == '.')
       {
@@ -676,7 +678,7 @@ if ((sp = malloc(strlen(VSYSNAME.nodename)+1)) == NULL)
 
 strcpy(sp,VSYSNAME.nodename);
 
-for (sp2=sp; *sp2 != NULL; sp2++)  /* Truncate fully qualified name */
+for (sp2=sp; *sp2 != '\0'; sp2++)  /* Truncate fully qualified name */
    {
    if (*sp2 == '.')
       {
@@ -805,7 +807,7 @@ Debug("(END OF PARSING)\n");
 SetEnvironment()
 
 {
-VBUFF[0] = NULL;
+VBUFF[0] = '\0';
 
 /* Define an environment variable here with all static classes ? */
 }
@@ -826,31 +828,53 @@ if (DEBUG || D2)
    printf("Sensible size = %d\n",SENSIBLEFSSIZE);
    printf("Sensible count = %d\n",SENSIBLEFILECOUNT);
    printf("Edit File (Max) Size = %d\n\n",EDITFILESIZE);
+   printf("------------------------------------------------------------\n");
    ListDefinedBinservers();
+   printf("------------------------------------------------------------\n");
    ListDefinedHomeservers();
+   printf("------------------------------------------------------------\n");
    ListDefinedHomePatterns();
+   printf("------------------------------------------------------------\n");
    ListActionSequence();
    printf("\nUsing mailserver %s\n",VMAILSERVER);
    printf("\nLocal mountpoint is %s\n",VMOUNTPATH);
    printf("\nDefault route for packets %s\n\n",VDEFAULTROUTE);
    printf("\nFile repository = %s\n\n",VREPOSITORY);
+   printf("------------------------------------------------------------\n");
    ListDefinedLinks();
+   printf("------------------------------------------------------------\n");
    ListDefinedLinkchs();
+   printf("------------------------------------------------------------\n");
    ListDefinedResolvers();
+   printf("------------------------------------------------------------\n");
    ListDefinedScripts();
+   printf("------------------------------------------------------------\n");
    ListDefinedImages();
+   printf("------------------------------------------------------------\n");
    ListDefinedTidy();
+   printf("------------------------------------------------------------\n");
    ListDefinedRequired();
+   printf("------------------------------------------------------------\n");
    ListDefinedMountables();
+   printf("------------------------------------------------------------\n");
    ListMiscMounts();
+   printf("------------------------------------------------------------\n");
    ListFiles();
+   printf("------------------------------------------------------------\n");
    ListDefinedDisable();
+   printf("------------------------------------------------------------\n");
    ListDefinedMakePaths();
+   printf("------------------------------------------------------------\n");
    ListDefinedIgnore();
+   printf("------------------------------------------------------------\n");
    ListDefinedImports();
+   printf("------------------------------------------------------------\n");
    ListFileEdits();
+   printf("------------------------------------------------------------\n");
    ListUnmounts();
+   printf("------------------------------------------------------------\n");
    ListProcesses();
+   printf("------------------------------------------------------------\n");
    }
 }
 
@@ -939,12 +963,12 @@ cbuff[0]='\0';
 actiontxt[0]='\0';
 sp = action;
 
-while (*sp != NULL)
+while (*sp != '\0')
    {
    ++j;
    sscanf(sp,"%[^.]",cbuff);
 
-   while ((*sp != NULL) && (*sp !='.'))
+   while ((*sp != '\0') && (*sp !='.'))
       {
       sp++;
       }
@@ -974,14 +998,14 @@ while (*sp != NULL)
 
 BuildClassEnvironment();
 
-if (VERBOSE || DEBUG || D2)
+if ((VERBOSE || DEBUG || D2) && *classlist != NULL)
    {
-   printf("\nTemporary class additions = ( ");
+   printf("\n                  New temporary class additions\n");
+   printf("                  -----------------------------\n");
    for (ip = *classlist; ip != NULL; ip=ip->next)
       {
-      printf("%s ",ip->name);
+      printf("                             %s\n",ip->name);
       }
-   printf("):\n");
    }
 
 for (i = 0; ACTIONSEQTEXT[i] != NULL; i++)
@@ -1003,10 +1027,7 @@ MakePaths()
   char *sp;
   struct stat statbuf;
 
-if (DEBUG || D2 || VERBOSE)
-   {
-   printf("\ncfengine: checking directories:\n");
-   }
+Banner("cfengine: checking directories:");
 
 for (ip = VMAKEPATH; ip != NULL; ip=ip->next)
    {
@@ -1015,7 +1036,7 @@ for (ip = VMAKEPATH; ip != NULL; ip=ip->next)
       continue;
       }
 
-   CURRENTPATH[0] = NULL;
+   CURRENTPATH[0] = '\0';
    ExpandVarstring(ip->path,CURRENTPATH,"");
 
    if (CURRENTPATH[strlen(CURRENTPATH)-1] != '/')
@@ -1056,7 +1077,7 @@ if (NOLINKS)
    return;
    }
 
-Verbose("\ncfengine: Checking links:\n");
+Banner("cfengine: Checking links:");
 
 for (lp = VLINK; lp != NULL; lp = lp->next)
    {
@@ -1094,7 +1115,7 @@ for (lp = VLINK; lp != NULL; lp = lp->next)
 
    for( ip = VBINSERVERS; ip != NULL && (!matched); ip = ip->next)
       {
-      CURRENTPATH[0] = CURRENTITEM[0] = NULL;
+      CURRENTPATH[0] = CURRENTITEM[0] = '\0';
 
       varstring = ExpandVarbinserv(lp->to,CURRENTPATH,ip->name);
 
@@ -1141,7 +1162,7 @@ if (NOLINKS)
    return;
    }
 
-Verbose("\ncfengine: Checking multiple childlinks:\n");
+Banner("cfengine: Checking multiple childlinks:");
 
 for (lp = VCHLINK; lp != NULL; lp = lp->next)
    {
@@ -1160,7 +1181,7 @@ for (lp = VCHLINK; lp != NULL; lp = lp->next)
 
    for( ip = VBINSERVERS; ip != NULL && (!matched); ip = ip->next)
       {
-      CURRENTPATH[0] = CURRENTITEM[0] = NULL;
+      CURRENTPATH[0] = CURRENTITEM[0] = '\0';
 
       if (strcmp(lp->to,"linkchildren") == 0)           /* linkchildren */
          {
@@ -1222,7 +1243,7 @@ if (getuid() != 0)
    return;
    }
 
-Verbose("\ncfengine: mounting filesystems\n");
+Banner("cfengine: mounting filesystems");
 
 if ((pp = popen(VMOUNTCOMM[VSYSTEMHARDCLASS],"r")) == NULL)
    {
@@ -1259,7 +1280,7 @@ while (!feof(pp))
       }
    }
 
-fclose(pp);
+pclose(pp);
 }
 
 /*******************************************************************/
@@ -1271,7 +1292,7 @@ GetMountInfo ()  /* This is, in fact, the most portable way to read the mount in
   char buf1[bufsize],buf2[bufsize],buf3[bufsize];
   char host[maxvarsize], mounton[bufsize];
 
-Verbose("\ncfengine: Building list of currently mounted filesystems\n");
+Banner("cfengine: Building list of currently mounted filesystems");
 
 sscanf(VMOUNTCOMM[VSYSTEMHARDCLASS],"%s",buf1); /* extract mount path */
 
@@ -1283,7 +1304,7 @@ if ((pp = popen(buf1,"r")) == NULL)
 
 do
    {
-   VBUFF[0] = buf1[0] = buf2[0] = buf3[0] = NULL;
+   VBUFF[0] = buf1[0] = buf2[0] = buf3[0] = '\0';
 
    fgets(VBUFF,bufsize,pp);
    sscanf(VBUFF,"%s%s%s",buf1,buf2,buf3);
@@ -1318,7 +1339,7 @@ do
          printf("%s\n",VBUFF);
          }
       GOTMOUNTINFO = false;
-      fclose(pp);
+      pclose(pp);
       return;
       }
 
@@ -1393,7 +1414,7 @@ do
 
 while (!feof(pp));
 
-fclose(pp);
+pclose(pp);
 }
 
 /*******************************************************************/
@@ -1418,7 +1439,7 @@ if (getuid() != 0)
    return;
    }
 
-Verbose("\ncfengine: Checking home and binservers\n");
+Banner("cfengine: Checking home and binservers");
 
 for (mp = VMOUNTABLES; mp != NULL; mp=mp->next)
    {
@@ -1489,7 +1510,7 @@ if (getuid() != 0)
    return;
    }
 
-Verbose("\ncfengine: Checking miscellaneous mountables:\n");
+Banner("cfengine: Checking miscellaneous mountables:");
 
 for (mp = VMISCMOUNT; mp != NULL; mp=mp->next)
    {
@@ -1532,7 +1553,7 @@ Unmount()
   struct stat statbuf;
   FILE *pp;
 
-Verbose("\ncfengine: checking unmounts\n");
+Banner("cfengine: checking unmounts");
 
 if (getuid() != 0)                            
    {
@@ -1666,12 +1687,11 @@ DeleteItemList(filelist);
 CheckRequired()
 
 { struct Item *rp;
-  char *sp, *bp;
   struct Item *ip;
   int matched,varstring,missing = 0;
-  struct stat statbuf;
 
-Verbose("\ncfengine: checking required filesystems\n");
+
+Banner("cfengine: checking required filesystems");
 
 for (rp = VREQUIRED; rp != NULL; rp = rp->next)
    {
@@ -1684,7 +1704,7 @@ for (rp = VREQUIRED; rp != NULL; rp = rp->next)
 
    for( ip = VBINSERVERS; ip != NULL && (!matched); ip = ip->next)
       {
-      CURRENTPATH[0] = CURRENTITEM[0] = NULL;
+      CURRENTPATH[0] = CURRENTITEM[0] = '\0';
 
       varstring = ExpandVarbinserv(rp->name,CURRENTPATH,ip->name);
 
@@ -1737,12 +1757,12 @@ MailCheck()
   char lmailpath[maxvarsize];
 
 
-if (VMAILSERVER[0] == NULL)
+if (VMAILSERVER[0] == '\0')
    {
    FatalError("Program does not define a mailserver for this host");
    }
 
-Verbose("\ncfengine: checking mail spool directory\n\n");
+Banner("cfengine: checking mail spool directory");
 
 if (getuid() != 0)                            
    {
@@ -1752,7 +1772,7 @@ if (getuid() != 0)
 
 sscanf (VMAILSERVER,"%[^:]:%s",mailhost,rmailpath);
 
-if (VMAILSERVER[0] == NULL)
+if (VMAILSERVER[0] == '\0')
    {
    printf("\ncfengine: WARNING: Host has no defined mailserver!\n");
    return;
@@ -1821,8 +1841,6 @@ TidyFiles()
    /* After that's finished, we go snooping around the homedirs */
 
 { char basename[bufsize],pathbuff[bufsize];
-  DIR *dirh;
-  struct dirent *dirp;
   struct TidyPattern *tlp;
   struct Tidy *tp;
   struct Item *ip;
@@ -1831,7 +1849,7 @@ TidyFiles()
   int TidyWrapper();
   int RecHomeTidyWrapper();
 
-Verbose ("\ncfengine: tidying by path\n");
+Banner("cfengine: tidying by path");
 
 for (tp = VTIDY; tp != NULL; tp=tp->next)
    {
@@ -1926,9 +1944,9 @@ else
    {
    while (!feof(fp))
       {
-      VBUFF[0] = NULL;
+      VBUFF[0] = '\0';
       fgets (VBUFF,bufsize,fp);
-      VBUFF[strlen(VBUFF)-1] = NULL;        /* chop */
+      VBUFF[strlen(VBUFF)-1] = '\0';        /* chop */
 
       if (strlen(VBUFF) == 0)
          {
@@ -1982,7 +2000,7 @@ CheckFiles()                         /* Check through file systems */
   short savetravlinks = TRAVLINKS;
   short savekilloldlinks = KILLOLDLINKS;
 
-Verbose("\ncfengine: checking files\n");
+Banner("cfengine: checking files");
 
 if (TRAVLINKS && (VERBOSE || DEBUG || D2))
    {
@@ -2086,7 +2104,7 @@ DisableFiles()
 { struct Disable *dp;
   struct stat statbuf;
 
-Verbose("\ncfengine: checking files to disable\n");
+Banner("cfengine: checking files to disable");
 
 for (dp = VDISABLELIST; dp != NULL; dp=dp->next)
    {
@@ -2201,6 +2219,8 @@ Scripts()
 
 { struct Item *ptr;
 
+Banner("cfengine: Running shell commands");
+
 for (ptr = VSCRIPT; ptr != NULL; ptr=ptr->next)
    {
    if (IsExcluded(ptr->classes))
@@ -2227,7 +2247,7 @@ EditFiles()
 
 { struct Edit *ptr;
 
-Verbose("\ncfengine: editing files\n");
+Banner("cfengine: editing files");
 
 for (ptr=VEDITLIST; ptr!=NULL; ptr=ptr->next)
    {
@@ -2251,7 +2271,7 @@ MakeImages()
 { struct Image *ip;
   struct stat statbuf;
 
-Verbose("\ncfengine: Checking file images:\n");
+Banner("cfengine: Checking file images:");
 
 for (ip = VIMAGE; ip != NULL; ip=ip->next)
    {
@@ -2280,6 +2300,11 @@ for (ip = VIMAGE; ip != NULL; ip=ip->next)
 	 }
       else
 	 {
+	 if (! MakeDirectoriesFor(ip->destination))
+            {
+            return;
+            }
+
 	 CheckImage(ip->path,ip->destination,ip);
 	 }
       }
@@ -2324,7 +2349,7 @@ CheckResolv()
 { struct Item *filebase = NULL;
   struct Item *ip;
   FILE *fp;
-  char *sp, ch;
+  char ch;
 
 
 if (VDOMAIN == NULL)
@@ -2350,12 +2375,12 @@ else
 
       if(VBUFF[strlen(VBUFF)-1] == '\n')
          {
-         VBUFF[strlen(VBUFF)-1] = NULL;        /* chop */
+         VBUFF[strlen(VBUFF)-1] = '\0';        /* chop */
          }
 
       AppendItem(&filebase,VBUFF,NULL);
 
-      VBUFF[0] = NULL;
+      VBUFF[0] = '\0';
       }
 
    fclose(fp);
@@ -2454,7 +2479,7 @@ char *var;
 
 { int i;
 
-for (i = 0; VRESOURCES[i] != NULL; i++)
+for (i = 0; VRESOURCES[i] != '\0'; i++)
    {
    if (strcmp(VRESOURCES[i],var)==0)
       {
@@ -2611,7 +2636,7 @@ for (ptr = VNEGHEAP; ptr != NULL; ptr=ptr->next)
    printf("%s ",ptr->name);
    }
 
-printf (")\n");
+printf (")\n\n");
 
 printf ("Installable classes = ( ");
 
@@ -2712,7 +2737,7 @@ ListDefinedLinks()
 { struct Link *ptr;
   struct Item *ip;
   
-printf ("\nDefined Links = ( ");
+printf ("\nDEFINED LINKS\n\n");
 
 for (ptr = VLINK; ptr != NULL; ptr=ptr->next)
    {
@@ -2732,8 +2757,6 @@ for (ptr = VLINK; ptr != NULL; ptr=ptr->next)
       printf(" Include %s\n",ip->name);
       }
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2743,7 +2766,7 @@ ListDefinedLinkchs()
 { struct Link *ptr;
   struct Item *ip;
 
-printf ("\nDefined Child Links = ( ");
+printf ("\nDEFINED CHILD LINKS\n\n");
 
 for (ptr = VCHLINK; ptr != NULL; ptr=ptr->next)
    {
@@ -2765,8 +2788,6 @@ for (ptr = VCHLINK; ptr != NULL; ptr=ptr->next)
       printf(" Include %s\n",ip->name);
       }
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2775,7 +2796,7 @@ ListDefinedResolvers()
 
 { struct Item *ptr;
 
-printf ("\nDefined Nameservers = ( ");
+printf ("\nDEFINED NAMESERVERS\n\n");
 
 for (ptr = VRESOLVE; ptr != NULL; ptr=ptr->next)
    {
@@ -2791,14 +2812,12 @@ ListDefinedScripts()
 
 { struct Item *ptr;
 
-printf ("\nDefined shellcommands = \n(\n");
+printf ("\nDEFINED SHELLCOMMANDS\n\n");
 
 for (ptr = VSCRIPT; ptr != NULL; ptr=ptr->next)
    {
    printf("%s\n",ptr->name);
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2808,60 +2827,70 @@ ListDefinedImages()
 { struct Image *ptr;
   struct UidList *up;
   struct GidList *gp;
-  struct Image *ip;
   struct Item *iip;
   
-printf ("\nDefined file images = ( ");
+printf ("\nDEFINED FILE IMAGES\n\n");
 
 for (ptr = VIMAGE; ptr != NULL; ptr=ptr->next)
    {
-   printf("[%s,+%o,-%o,%s,(%s),r=%d]\n",ptr->path,ptr->plus,ptr->minus,
-	  ptr->destination,ptr->action,ptr->recurse);
+   printf("\n%s\n +%o\n -%o\n dest: %s\n action: %s\n",ptr->path,ptr->plus,ptr->minus,
+	  ptr->destination,ptr->action);
   
-   printf("uids = ( ");
+   if (ptr->recurse == INFINITERECURSE)
+      {
+      printf(" recurse=inf\n");
+      }
+   else
+      {
+      printf(" recurse=%d\n",ptr->recurse);
+      }
+   
+   printf(" uids = ( ");
 
    for (up = ptr->uid; up != NULL; up=up->next)
       {
       printf("%d ",up->uid);
       }
 
-   printf("), gids = ( ");
+   printf(")\n gids = ( ");
 
    for (gp = ptr->gid; gp != NULL; gp=gp->next)
       {
       printf("%d ",gp->gid);
       }
 
-   printf(")\n");
+   printf(")\n exclude:");
 
    for (iip = ptr->exclusions; iip != NULL; iip = iip->next)
       {
-      printf(" Exclude %s\n",iip->name);
+      printf(" %s",iip->name);
       }
+   
    printf("\n");
+   printf(" symlink:");
 
    for (iip = ptr->symlink; iip != NULL; iip = iip->next)
       {
-      printf(" Symlink %s\n",iip->name);
+      printf(" %s",iip->name);
       }
-   printf("\n");
-
+   
+   printf("\n include:");
+   
    for (iip = ptr->inclusions; iip != NULL; iip = iip->next)
       {
-      printf(" Include %s\n",iip->name);
+      printf(" %s",iip->name);
       }
    printf("\n");
    
-   printf("Classes = %s\n",ptr->classes);
+   printf(" classes = %s\n",ptr->classes);
+
+   printf(" method = %c (time/checksum)\n",ptr->type);
 
-   printf("Method = %c (time/checksum)\n",ptr->type);
-   
    if (! ptr->backup)
       {
-      printf("NOT BACKED UP\n");
+      printf(" NOT BACKED UP\n");
       }
    }
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2871,18 +2900,26 @@ ListDefinedTidy()
 { struct Tidy *ptr;
   struct TidyPattern *tp;
 
-printf ("\nDefined tidy masks =");
+printf ("\nDEFINED TIDY MASKS\n\n");
 
 for (ptr = VTIDY; ptr != NULL; ptr=ptr->next)
    {
    printf("  path=%s\n",ptr->path);
    for(tp = ptr->tidylist; tp != NULL; tp=tp->next)
       {
-      printf("    pat=%s, %c-age=%d, size=%d, recurse=%d\n",tp->pattern,tp->searchtype,tp->age,tp->size,tp->recurse);
+      printf("    pat=%s, %c-age=%d, size=%d, linkdirs=%c, ",
+	     tp->pattern,tp->searchtype,tp->age,tp->size,tp->dirlinks);
+
+      if (tp->recurse == INFINITERECURSE)
+	 {
+	 printf("recurse=inf\n");
+	 }
+      else
+	 {
+	 printf("recurse=%d\n",tp->recurse);
+	 }
       }
    }
-
-printf ("\n");
 }
 
 /*********************************************************************/
@@ -2891,14 +2928,12 @@ ListDefinedMountables()
 
 { struct Item *ptr;
 
-printf ("\nDefined mountables = ( ");
+printf ("\nDEFINED MOUNTABLES\n\n");
 
 for (ptr = VMOUNTABLES; ptr != NULL; ptr=ptr->next)
    {
-   printf("%s ",ptr->name);
+   printf("%s\n",ptr->name);
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2907,7 +2942,7 @@ ListMiscMounts()
 
 { struct MiscMount *ptr;
 
-printf ("\nMiscellaneous mountables = ( ");
+printf ("\nDEFINED MISC MOUNTABLES\n\n");
 
 for (ptr = VMISCMOUNT; ptr != NULL; ptr=ptr->next)
    {
@@ -2923,14 +2958,12 @@ ListDefinedRequired()
 
 { struct Item *ptr;
 
-printf ("\nDefined requirements = ( ");
+printf ("\nDEFINED REQUIRE\n\n");
 
 for (ptr = VREQUIRED; ptr != NULL; ptr=ptr->next)
    {
    printf("%s\n",ptr->name);
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2955,14 +2988,12 @@ ListDefinedDisable()
 
 { struct Disable *ptr;
 
-printf ("\nDefined disable items = ( ");
+printf ("\nDEFINED DISABLE\n\n");
 
 for (ptr = VDISABLELIST; ptr != NULL; ptr=ptr->next)
    {
-   printf("%s: rotate=%d, type=%s,",ptr->name,ptr->rotate,ptr->type);
+   printf("%s: rotate=%d, type=%s\n",ptr->name,ptr->rotate,ptr->type);
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -2973,20 +3004,29 @@ ListDefinedMakePaths()
   struct UidList *up;
   struct GidList *gp;
 
-printf ("\nDefined directories = ( ");
+printf ("\nDEFINED DIRECTORIES\n\n");
 
 for (ptr = VMAKEPATH; ptr != NULL; ptr=ptr->next)
    {
-   printf("[%s,+%o,-%o,%s,%d]\n",ptr->path,ptr->plus,ptr->minus,FILEACTIONTEXT[ptr->action],ptr->recurse);
-  
-   printf("uids = ( ");
+   printf("%s\n +%o\n -%o\n %s\n",ptr->path,ptr->plus,ptr->minus,FILEACTIONTEXT[ptr->action]);
+
+   if (ptr->recurse == INFINITERECURSE)
+      {
+      printf(" recurse=inf\n");
+      }
+   else
+      {
+      printf(" recurse=%d\n",ptr->recurse);
+      }
+   
+   printf(" uids = ( ");
 
    for (up = ptr->uid; up != NULL; up=up->next)
       {
       printf("%d ",up->uid);
       }
 
-   printf("), gids = ( ");
+   printf(")\n gids = ( ");
 
    for (gp = ptr->gid; gp != NULL; gp=gp->next)
       {
@@ -2994,8 +3034,6 @@ for (ptr = VMAKEPATH; ptr != NULL; ptr=ptr->next)
       }
    printf(")\n");
    }
-printf (")\n");
-
 }
 
 /*********************************************************************/
@@ -3004,14 +3042,12 @@ ListDefinedImports()
 
 { struct Item *ptr;
 
-printf ("\nDefined files to be imported = ( ");
+printf ("\nDEFINED IMPORTS\n\n");
 
 for (ptr = VIMPORT; ptr != NULL; ptr=ptr->next)
    {
-   printf("%s ",ptr->name);
+   printf("%s\n",ptr->name);
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -3020,14 +3056,12 @@ ListDefinedIgnore()
 
 { struct Item *ptr;
 
-printf ("\nDefined ignore items = ( ");
+printf ("\nDEFINED IGNORE\n\n");
 
 for (ptr = VIGNORE; ptr != NULL; ptr=ptr->next)
    {
    printf("%s\n",ptr->name);
    }
-
-printf (")\n");
 }
 
 /*********************************************************************/
@@ -3038,20 +3072,30 @@ ListFiles()
   struct UidList *up;
   struct GidList *gp;
 
-printf ("\nDefined file actions = ( ");
+printf ("\nDEFINED FILES\n\n");
 
 for (ptr = VFILE; ptr != NULL; ptr=ptr->next)
    {
-   printf("[%s,+%o,-%o,%s,%d,%c]\n",ptr->path,ptr->plus,ptr->minus,FILEACTIONTEXT[ptr->action],ptr->recurse,ptr->travlinks);
-  
-   printf("uids = ( ");
+   printf("\n%s\n +%o\n -%o\n %s\n travelinks=%c\n",
+	  ptr->path,ptr->plus,ptr->minus,FILEACTIONTEXT[ptr->action],ptr->travlinks);
+
+   if (ptr->recurse == INFINITERECURSE)
+      {
+      printf(" recurse=inf\n");
+      }
+   else
+      {
+      printf(" recurse=%d\n",ptr->recurse);
+      }
+   
+   printf(" uids = ( ");
 
    for (up = ptr->uid; up != NULL; up=up->next)
       {
       printf("%d ",up->uid);
       }
 
-   printf("), gids = ( ");
+   printf(")\n gids = ( ");
 
    for (gp = ptr->gid; gp != NULL; gp=gp->next)
       {
@@ -3059,7 +3103,6 @@ for (ptr = VFILE; ptr != NULL; ptr=ptr->next)
       }
    printf(")\n");
    }
-printf (")\n");
 }
 
 /*******************************************************************/
@@ -3084,14 +3127,12 @@ ListUnmounts()
 
 { struct Item *ptr;
 
-printf("\nUnmount items = (");
+printf("\nDEFINED UNMOUNTS\n\n");
 
 for (ptr=VUNMOUNT; ptr!=NULL; ptr=ptr->next)
    {
    printf("%s ",ptr->name);
    }
-
-printf(")\n");
 }
 
 /*******************************************************************/
@@ -3101,7 +3142,7 @@ ListProcesses()
 { struct Process *ptr;
   char *sp;
 
-printf("\nProcess items = (\n");
+printf("\nDEFINED PROCESSES\n\n");
 
 for (ptr = VPROCLIST; ptr != NULL; ptr=ptr->next)
    {
@@ -3114,7 +3155,7 @@ for (ptr = VPROCLIST; ptr != NULL; ptr=ptr->next)
       sp = ptr->restart;
       }
    
-   printf("%s res %s, m= %c%d, s=%s, act=%c\n",ptr->expr,sp,ptr->comp,ptr->matches,
+   printf("%s\n Restart = %s\n matches: %c%d\n signal=%s\n action=%c\n\n",ptr->expr,sp,ptr->comp,ptr->matches,
 	  SIGNALS[ptr->signal],ptr->action);
    }
 
@@ -3128,26 +3169,24 @@ ListFileEdits()
 { struct Edit *ptr;
   struct Edlist *ep;
 
-printf("\nFile edits = \n(\n");
+printf("\nDEFINED FILE EDITS\n\n");
 
 for (ptr=VEDITLIST; ptr!=NULL; ptr=ptr->next)
    {
-   printf("%s=\n",ptr->fname);
+   printf("%s\n",ptr->fname);
    for (ep = ptr->actions; ep != NULL; ep=ep->next)
       {
       if (ep->data == NULL)
          {
-         printf("(%s,[nodata])\n",VEDITNAMES[ep->code]);
+         printf(" %s [nodata]\n",VEDITNAMES[ep->code]);
          }
       else
          {
-         printf("(%s,[%s])\n",VEDITNAMES[ep->code],ep->data);
+         printf(" %s [%s]\n",VEDITNAMES[ep->code],ep->data);
          }
       }
    printf("\n");
    }
-
-printf("\n)\n");
 }
 
 /*******************************************************************/
@@ -3415,9 +3454,7 @@ CheckHome(ptr)                      /* iterate check over homedirs */
 
 struct File *ptr;
 
-{ DIR *dirh;
-  struct dirent *dirp;
-  int RecFileCheck();
+{ int RecFileCheck();
   struct Item *ip;
   char basename[bufsize],pathbuff[bufsize];
 
@@ -3518,7 +3555,7 @@ if (stat(startpath,&statbuf) == -1)
       {
       MakeDirectoriesFor(startpath);
       ptr->action = fixall;
-      *(startpath+strlen(ptr->path)-2) = NULL;       /* trunc /. */
+      *(startpath+strlen(ptr->path)-2) = '\0';       /* trunc /. */
          CheckExistingFile(startpath,ptr->plus,ptr->minus,ptr->action,ptr->uid,ptr->gid,&statbuf);
       return;
       }
