@@ -202,7 +202,7 @@ char *VPSOPTS[clssattr] =
    "-ax",    /* ultrix */
    "-ef",     /* hp10 */
    "-ef",    /* houx */
-   "-ax",    /* aix */
+   "-ef",    /* aix */
    "-ax",    /* linux */
    "-ef",    /* solaris */
    "-ax",    /* osf1 */
