@@ -43,7 +43,7 @@ char *file;
 
 { struct Edit *ptr;
 
-VBUFF[0]=NULL;                         /* Expand any variables */
+VBUFF[0]='\0';                         /* Expand any variables */
 ExpandVarstring(file,VBUFF,"");
 
 for (ptr=VEDITLIST; ptr != NULL; ptr=ptr->next)
@@ -80,7 +80,7 @@ if ( ! IsInstallable(CLASSBUFF))
    return;
    }
 
-VBUFF[0]=NULL;                         /* Expand any variables */
+VBUFF[0]='\0';                         /* Expand any variables */
 ExpandVarstring(file,VBUFF,"");
 
 if ((ptr = (struct Edit *)malloc(sizeof(struct Edit))) == NULL)
@@ -144,7 +144,7 @@ if ( ! IsInstallable(CLASSBUFF))
 
 for (ptr = VEDITLIST; ptr != NULL; ptr=ptr->next)
    {
-   varbuff[0] = NULL;
+   varbuff[0] = '\0';
    ExpandVarstring(file,varbuff,"");
 
    if (strcmp(ptr->fname,varbuff) == 0)
@@ -172,7 +172,7 @@ for (ptr = VEDITLIST; ptr != NULL; ptr=ptr->next)
          }
       else
          {
-         VBUFF[0]=NULL;                         /* Expand any variables */
+         VBUFF[0]='\0';                         /* Expand any variables */
          ExpandVarstring(data,VBUFF,"");
 
          if ((datstring = malloc(strlen(VBUFF)+1)) == NULL)
@@ -240,7 +240,7 @@ char *edit;
 
 Debug2("EditActionsToCode(%s)\n",edit);
 
-for (i = 0; VEDITNAMES[i] != NULL; i++)
+for (i = 0; VEDITNAMES[i] != '\0'; i++)
    {
    if (strcmp(VEDITNAMES[i],edit) == 0)
       {
@@ -609,7 +609,7 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                break;
 
       case LocateLineMatching:
-               newlineptr = LocateItemMatchingRegExp(filestart,ep->data);
+               newlineptr = LocateItemMatchingRegExp(CURRENTLINEPTR,ep->data);
 
                if (newlineptr == NULL)
                   {
@@ -692,6 +692,15 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                   goto abort;
                   }
                break;
+	       
+      case UnCommentNLines:
+               if (! UnCommentSeveralLines(&filestart,ep->data,COMMENTSTART,COMMENTEND))
+                  {
+                  EditVerbose("cfengine: Could not comment %s lines from file\n",ep->data);
+                  EditVerbose("          Aborting file editing of %s.\n",filename);
+                  goto abort;
+                  }
+               break;	       
 
       case SetScript:
                currenteditscript = ep->data;
@@ -730,6 +739,7 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
       case EmptyEntireFilePlease:
                EditVerbose("Edit: Emptying entire file\n");
                DeleteItemList(filestart);
+	       filestart = NULL;
                NUMBEROFEDITS++;
                break;
 
@@ -816,7 +826,7 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
 	       break;
 
       case AutoMountDirectResources:
-	       HandleAutomountRescources(filestart,ep->data);
+	       HandleAutomountRescources(&filestart,ep->data);
 	       break;
 
       default: printf("cfengine: Unknown action in editing of file %s\n",filename);
@@ -906,7 +916,7 @@ ResetEditSearch (str,list)
 char *str;
 struct Item *list;
 
-{ int i = 0 ,n = -1;
+{ int i = 1 ,n = -1;
   struct Item *ip;
 
 sscanf(str,"%d", &n);
@@ -927,7 +937,7 @@ if (i < n || ip == NULL)
    return false;
    }
 
-EditVerbose("Edit: resetting pointers to line %d\n");
+EditVerbose("Edit: resetting pointers to line %d\n",n);
 
 CURRENTLINENUMBER = n;
 CURRENTLINEPTR = ip;
@@ -1038,7 +1048,7 @@ struct Item *list;
 char *type;
 
 { struct Item *ip;
-  char *sp, *cp;
+  char *sp;
   int gotCR;
 
 EditVerbose("Edit: Checking end of line conventions: type = %s\n",type);
@@ -1047,7 +1057,7 @@ if (strcmp("unix",type) == 0 || strcmp("UNIX",type) == 0)
    {
    for (ip = list; ip != NULL; ip=ip->next)
       {
-      for (sp = ip->name; *sp != NULL; sp++)
+      for (sp = ip->name; *sp != '\0'; sp++)
 	 {
 	 if (*sp == (char)13)
 	    {
@@ -1065,7 +1075,7 @@ if (strcmp("dos",type) == 0 || strcmp("DOS",type) == 0)
       {
       gotCR = false;
       
-      for (sp = ip->name; *sp !=NULL; sp++)
+      for (sp = ip->name; *sp !='\0'; sp++)
 	 {
 	 if (*sp == (char)13)
 	    {
@@ -1090,7 +1100,7 @@ printf("cfengine: Unknown file format: %s\n",type);
 
 HandleAutomountRescources(filestart,opts)
 
-struct Item *filestart;
+struct Item **filestart;
 char *opts;
 
 { struct Item *ip;
@@ -1106,9 +1116,9 @@ for (ip = VMOUNTABLES; ip != NULL; ip=ip->next)
    sp++;
    sprintf(buffer,"%s\t%s\t%s",sp,opts,ip->name);
 
-   if (LocateNextItemContaining(filestart,sp) == NULL)
+   if (LocateNextItemContaining(*filestart,sp) == NULL)
       {
-      AppendItem(&filestart,buffer,"");
+      AppendItem(filestart,buffer,"");
       NUMBEROFEDITS++;
       }
    else
