@@ -56,12 +56,12 @@ if (strcmp("any",str) == 0)
 
 CLASS = empty;
 
-for (sp = str; *sp != NULL; sp++)
+for (sp = str; *sp != '\0'; sp++)
    {
    *sp = ToLower(*sp);
    }
 
-for (i = 1; CLASSTEXT[i] != NULL; i++)
+for (i = 1; CLASSTEXT[i] != '\0'; i++)
    {
    if (strcmp(CLASSTEXT[i],str) == 0)
       {
@@ -97,9 +97,7 @@ AddClassToHeap(class)
 
 char *class;
 
-{ struct Item *ptr;
-  char *sp;
-
+{
 if (IsItemIn(VHEAP,class))
    {
    return;
@@ -121,7 +119,7 @@ char *sp;
 
 Debug("IsHardClass(%s)",sp);
 
-for (i = 2; CLASSTEXT[i] != NULL; i++)
+for (i = 2; CLASSTEXT[i] != '\0'; i++)
    {
    if (strcmp(CLASSTEXT[i],sp) == 0)
       {
@@ -174,11 +172,11 @@ char *class;
 { char *sp;
   int result = false;
 
-Debug2("IsDefinedClass(%s)\n",class);
+Debug1("IsDefinedClass(%s)\n",class);
 
-VBUFF[0] = NULL;
+VBUFF[0] = '\0';
 
-for (sp = class; *sp != NULL; sp+=strlen(VBUFF))
+for (sp = class; *sp != '\0'; sp+=strlen(VBUFF))
    {
    while (*sp == '|')
       {
@@ -216,9 +214,9 @@ if (DEBUG || D1)
    printf("IsInstallable(%s)\n",class);
    }
 
-VBUFF[0] = NULL;
+VBUFF[0] = '\0';
 
-for (sp = class; *sp != NULL; sp+=strlen(VBUFF))
+for (sp = class; *sp != '\0'; sp+=strlen(VBUFF))
    {
    while (*sp == '|')
       {
@@ -249,11 +247,11 @@ char *class;
 
 Debug1("AddCompoundClass(%s)",class);
 
-while(*sp != NULL)
+while(*sp != '\0')
    {
    sscanf(sp,"%[^.]",cbuff);
 
-   while ((*sp != NULL) && (*sp !='.'))
+   while ((*sp != '\0') && (*sp !='.'))
       {
       sp++;
       }
@@ -284,11 +282,11 @@ struct Item **heap;
 
 Debug1("AddCompoundClass(%s)",class);
 
-while(*sp != NULL)
+while(*sp != '\0')
    {
    sscanf(sp,"%[^.]",cbuff);
 
-   while ((*sp != NULL) && (*sp !='.'))
+   while ((*sp != '\0') && (*sp !='.'))
       {
       sp++;
       }
@@ -318,13 +316,12 @@ EvaluateANDString(class,addclasses)
 char *class;
 struct Item *addclasses;
 
-{ struct Item *ptr;
-  char *sp, *simpleid;
+{ char *sp, *simpleid;
   char cbuff[maxvarsize];
   int count = 1;          /* no. of members in class */
   int negation = false;
 
-Debug("EvaluateANDString(%s)={",class);
+Debug1("EvaluateANDString(%s)={",class);
 
 for (sp = class; *sp != '\0'; sp++)
    {
@@ -336,13 +333,13 @@ for (sp = class; *sp != '\0'; sp++)
 
 sp = class;
 
-while(*sp != NULL)
+while(*sp != '\0')
    {
    negation = false;
 
    sscanf(sp,"%[^.]",cbuff);
 
-   while ((*sp != NULL) && (*sp !='.'))
+   while ((*sp != '\0') && (*sp !='.'))
       {
       sp++;
       }
@@ -362,14 +359,12 @@ while(*sp != NULL)
 
    if (IsItemIn(VNEGHEAP,simpleid))
       {
-      Debug("negheap [%s]",simpleid);
+      Debug1("negheap [%s]",simpleid);
       return false;
       } 
 
    if (IsItemIn(VHEAP,simpleid))
       {
-      Debug("vheap [%s]",simpleid);
-
       if (negation)
          {
          return false;
@@ -401,7 +396,7 @@ while(*sp != NULL)
       }
    }
 
-Debug("}\n");
+Debug1("}\n");
 
 if (count == 0)
    {
