@@ -81,7 +81,6 @@ IfConf (class)
 enum classes class;
 
 { int sk, flags, metric, isnotsane = false;
-  struct sockaddr_in sin;
 
 if (getuid() != 0)                            
    {
@@ -89,12 +88,12 @@ if (getuid() != 0)
    return;
    }
 
-if (VNETMASK[0] == NULL)
+if (VNETMASK[0] == '\0')
    {
    FatalError("Program does not define a subnetmask");
    }
 
-if (VBROADCAST[0] == NULL)
+if (VBROADCAST[0] == '\0')
    {
    FatalError("Program does not define a broadcast mode for this host");
    }
@@ -149,7 +148,7 @@ enum classes class;
 
 { struct sockaddr_in *sin;
   struct sockaddr_in netmask;
-  int insane = false, i;
+  int insane = false;
   struct hostent *hp;
   struct in_addr inaddr;
 
@@ -230,7 +229,6 @@ enum classes class;
 
 { struct sockaddr_in *sin;
   struct sockaddr_in netmask, broadcast;
-  struct in_addr adr;
 
    /*********************************
 
@@ -275,7 +273,7 @@ if (ioctl(sk,SIOCSIFBRDADDR, (caddr_t) &IFR) == -1)
    return;
    } 
 
-if (sin->sin_addr.s_addr == NULL)
+if ((char *) sin->sin_addr.s_addr == NULL)
    {
    printf("cfengine : No broadcast address on socket after configuration!!\n");
    }
@@ -356,7 +354,7 @@ if (getuid() != 0)
    return;
    }
 
-if (VDEFAULTROUTE[0] == NULL)
+if (VDEFAULTROUTE[0] == '\0')
    {
    if (VERBOSE || DEBUG)
       {
