@@ -53,7 +53,7 @@ int maxrecurse;
   char newto[bufsize];
   void *bug_check;
 
-if (maxrecurse == 0)  /* reached depth limit */
+if (maxrecurse == -1)  /* reached depth limit */
    {
    Debug2("MAXRECURSE ran out, quitting at level %s with endlist = %d\n",from,ip->next);
    return;
@@ -74,6 +74,17 @@ if (strlen(from) == 0)     /* Check for root dir */
 
 bug_check = ip->next;
 
+  /* Check that dest dir exists before starting */
+
+strcpy(newto,to);
+AddSlash(newto);
+
+if (! MakeDirectoriesFor(newto))
+   {
+   printf("cfengine: Unable to make directory %s\n",from);
+   return;
+   }
+
 if ((dirh = opendir(from)) == NULL)
    {
    printf("cfengine: RecursiveImage(): Can't open directory [%s]\n",from);
@@ -149,7 +160,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
       }
    else
       {
-      CheckImage(from,to,ip);
+      CheckImage(newfrom,newto,ip);
       }
    }
 
@@ -168,7 +179,7 @@ struct Image *ip;
   char homedir[bufsize],dest[bufsize],vmountpath[bufsize];
   struct passwd *pw;
   struct stat statbuf;
-  uid_t request_uid = ip->uid->uid;  /* save if -1 */
+  int request_uid = ip->uid->uid;  /* save if -1 */
   
 if (!MountPathDefined())
    {
@@ -275,8 +286,6 @@ char *destination;
 struct Image *ip;
 
 { DIR *dirh;
-  int i,j;
-  char *sp;
   char sourcefile[bufsize];
   char sourcedir[bufsize];
   char destdir[bufsize];
@@ -306,11 +315,6 @@ if (S_ISDIR(sourcestatbuf.st_mode))
       return;
       }
 
-   if (! MakeDirectoriesFor(destdir))
-      {
-      return;
-      }
-
    if (chmod (destdir,sourcestatbuf.st_mode  & 07777) == -1)
       {
       perror("chmod");
@@ -550,7 +554,6 @@ else
          if (! silent && (VERBOSE || DEBUG))
             {
             printf ("cfengine: updating image %s from master %s\n",destfile,sourcefile);
-            printf ("          old file saved to %s.%s\n",destfile,CF_SAVED);
             }
 
          if (CopyReg(sourcefile,destfile,sourcestatbuf,deststatbuf))
@@ -595,7 +598,7 @@ else
          return;
          }
 
-      Verbose("cfengine: image file is up to date: %s\n",destfile);
+      Debug2("cfengine: image file is up to date: %s\n",destfile);
       }
    }
 }
@@ -757,7 +760,7 @@ while (true)
             printf ("cfengine: lseek in CopyReg, dest=%s\n", dest);
             perror("lseek");
             free(buf);
-            return;
+            return false;
             }
          last_write_made_hole = 1;
          }
