@@ -359,7 +359,7 @@ DeleteToRegExp(filestart,string)
 struct Item **filestart;
 char *string;
 
-{ struct Item *ip, *ip_prev, *ip_end;
+{ struct Item *ip, *ip_prev, *ip_end = NULL;
   char fastmap[(1 << BYTEWIDTH)];
   struct re_pattern_buffer buf;
   struct re_registers regs;
@@ -383,7 +383,7 @@ if ((err = re_compile_pattern(string,strlen(string),&buf)) != 0)
    {
    printf("cfengine: Regular expression error for %s\n",string);
    printf("          %s\n",err);
-   return NULL;
+   return false;
    }
 
 for (ip = CURRENTLINEPTR; (ip != NULL); ip=ip->next)
@@ -391,7 +391,7 @@ for (ip = CURRENTLINEPTR; (ip != NULL); ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if ((match = re_match(&buf,ip->name,strlen(ip->name),0,&regs)) == strlen(ip->name))
@@ -431,7 +431,7 @@ for (ip = CURRENTLINEPTR; ip != NULL; ip = CURRENTLINEPTR)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
 
    EditVerbose("Edit: delete line %s\n",ip->name);
@@ -466,14 +466,14 @@ DeleteItemStarting(list,string) /* deletes first item to match the string */
 struct Item **list;
 char *string;
 
-{ struct Item *ip, *next, *last;
+{ struct Item *ip, *next, *last = NULL;
 
 for (ip = *list; ip != NULL; ip=ip->next)
    {
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if (strncmp(ip->name,string,strlen(string)) == 0)
@@ -537,7 +537,7 @@ if ((err = re_compile_pattern(string,strlen(string),&buf)) != 0)
    {
    printf("cfengine: Regular expression error for %s\n",string);
    printf("          %s\n",err);
-   return NULL;
+   return false;
    }
 
 for (ip = *list; ip != NULL; ip=ip->next)
@@ -545,7 +545,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if ((match = re_match(&buf,ip->name,strlen(ip->name),0,&regs)) == strlen(ip->name))
@@ -600,7 +600,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if (strstr(ip->name,string))
@@ -867,7 +867,7 @@ while(!feof(fp))
 
    if(VBUFF[strlen(VBUFF)-1] == '\n')
       {
-      VBUFF[strlen(VBUFF)-1] = NULL;        /* chop */
+      VBUFF[strlen(VBUFF)-1] = '\0';        /* chop */
       }
 
    if (!feof(fp) || strlen(VBUFF) != 0) 
@@ -875,7 +875,7 @@ while(!feof(fp))
       AppendItem(liststart,VBUFF,NULL);
       }
 
-   VBUFF[0] = NULL;
+   VBUFF[0] = '\0';
    }
 
 fclose(fp);
@@ -918,7 +918,7 @@ if ((fp = fopen(file,"w")) == NULL)
    {
    printf("cfengine: Couldn't write file %s after editing\n",file);
    rename(VBUFF,file);
-   return NULL;
+   return false;
    }
 
 for (ip = liststart; ip != NULL; ip=ip->next)
@@ -954,7 +954,7 @@ CommentItemStarting(list,string,comm,end)
 struct Item **list;
 char *string,*comm,*end;
 
-{ struct Item *ip, *next, *last;
+{ struct Item *ip;
   char buff[bufsize];
 
 for (ip = *list; ip != NULL; ip=ip->next)
@@ -962,7 +962,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if (strncmp(ip->name,string,strlen(string)) == 0)
@@ -1006,7 +1006,7 @@ CommentItemContaining(list,string,comm,end)
 struct Item **list;
 char *string,*comm,*end;
 
-{ struct Item *ip, *next, *last;
+{ struct Item *ip;
   char buff[bufsize];
 
 for (ip = *list; ip != NULL; ip=ip->next)
@@ -1014,7 +1014,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if (strstr(ip->name,string))
@@ -1058,7 +1058,7 @@ CommentItemMatching(list,string,comm,end)
 struct Item **list;
 char *string,*comm,*end;
 
-{ struct Item *ip, *next, *last;
+{ struct Item *ip;
   char buff[bufsize];
   char fastmap[(1 << BYTEWIDTH)];
   struct re_pattern_buffer buf;
@@ -1075,7 +1075,7 @@ if ((err = re_compile_pattern(string,strlen(string),&buf)) != 0)
    {
    printf("cfengine: Regular expression error for %s\n",string);
    printf("          %s\n",err);
-   return NULL;
+   return false;
    }
 
 for (ip = *list; ip != NULL; ip=ip->next)
@@ -1083,7 +1083,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if ((match = re_match(&buf,ip->name,strlen(ip->name),0,&regs)) == strlen(ip->name))
@@ -1129,7 +1129,7 @@ CommentToRegExp(filestart,string,comm,end)
 struct Item **filestart;
 char *string, *comm, *end;
 
-{ struct Item *ip, *ip_end;
+{ struct Item *ip, *ip_end = NULL;
   char fastmap[(1 << BYTEWIDTH)];
   struct re_pattern_buffer buf;
   struct re_registers regs;
@@ -1153,7 +1153,7 @@ if ((err = re_compile_pattern(string,strlen(string),&buf)) != 0)
    {
    printf("cfengine: Regular expression error for %s\n",string);
    printf("          %s\n",err);
-   return NULL;
+   return false;
    }
 
 for (ip = CURRENTLINEPTR; (ip != NULL); ip=ip->next)
@@ -1161,7 +1161,7 @@ for (ip = CURRENTLINEPTR; (ip != NULL); ip=ip->next)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if ((match = re_match(&buf,ip->name,strlen(ip->name),0,&regs)) == strlen(ip->name))
@@ -1261,7 +1261,7 @@ for (ip = CURRENTLINEPTR; ip != NULL; ip = CURRENTLINEPTR)
    if (EDABORTMODE && ItemMatchesRegEx(ip->name,VEDITABORT))
       {
       Verbose("Aborting search, regex %s matches line\n",VEDITABORT);
-      return NULL;
+      return false;
       }
       
    if (ctr == N)
@@ -1348,7 +1348,7 @@ if ((err = re_compile_pattern(regexp,strlen(regexp),&buf)) != 0)
    {
    printf("cfengine: Regular expression error for %s\n",regexp);
    printf("          %s\n",err);
-   return NULL;
+   return false;
    }
 
 re_compile_fastmap (&buf);
@@ -1373,7 +1373,7 @@ struct Item **liststart;
 char *search, *replace;
 
 { int i;
-  char *sp, *start;
+  char *sp, *start = NULL;
   struct Item *ip;
   char fastmap[(1 << BYTEWIDTH)];
   struct re_pattern_buffer buf;
@@ -1391,7 +1391,7 @@ if ((err = re_compile_pattern(search,strlen(search),&buf)) != 0)
    {
    printf("cfengine: Regular expression error for %s\n",search);
    printf("          %s\n",err);
-   return NULL;
+   return false;
    }
 
 re_compile_fastmap (&buf);
@@ -1415,7 +1415,7 @@ for (ip = *liststart; ip != NULL; ip=ip->next)
    
    i = 0;
 
-   for (sp = ip->name; *sp != NULL; sp++)
+   for (sp = ip->name; *sp != '\0'; sp++)
       {
       if (sp != start)
          {
@@ -1424,7 +1424,7 @@ for (ip = *liststart; ip != NULL; ip=ip->next)
       else
          {
          sp += regs.end[0] - regs.start[0] - 1;
-         VBUFF[i] = NULL;
+         VBUFF[i] = '\0';
          strcat(VBUFF,replace);
          i += strlen(replace)-1;
 	 
@@ -1486,12 +1486,28 @@ ctr = 1;
 
 for (ip = CURRENTLINEPTR; ip != NULL; ip = CURRENTLINEPTR)
    {
+   if (ctr > N)
+      {
+      break;
+      }
+   
    if (ctr == N)
       {
       EditVerbose("Edit: terminating line: %s (Done)\n",ip->name);
       done = true;
       }
 
+   for (sp = ip->name; isspace(*sp); sp++)
+      {
+      }
+   
+   if (strncmp(sp,comm,strlen(comm)) == 0)
+      {
+      CURRENTLINEPTR = ip->next;
+      ctr++;
+      continue;
+      }
+
    EditVerbose("Edit: comment line %s\n",ip->name);
    NUMBEROFEDITS++;
    CURRENTLINEPTR = ip->next;
@@ -1528,6 +1544,121 @@ if (ctr-1 < N)
 return true;
 }
 
+/********************************************************************/
+
+UnCommentSeveralLines (filestart,string,comm,end)
+
+  /* Comments up to N lines from current position */
+
+struct Item **filestart;
+char *string, *comm, *end;
+
+{ struct Item *ip;
+  int ctr, N = -99, done = false;
+  char *sp, *sp1, *sp2, *spc;
+
+Debug2("UnCommentNLines(list,%s)\n",string);
+
+sscanf(string,"%d", &N);
+
+if (N < 1)
+   {
+   printf("cfengine: Illegal number value in CommentNLines: %s\n",string);
+   return false;
+   }
+
+
+if (CURRENTLINEPTR == NULL)  /* Shouldn't happen */
+   {
+   printf("cfengine: File line-pointer undefined during editfile action\n");
+   return true;
+   }
+
+ctr = 1;
+
+for (ip = CURRENTLINEPTR; ip != NULL; ip = CURRENTLINEPTR)
+   {
+   if (ctr > N)
+      {
+      break;
+      }
+   
+   if (ctr == N)
+      {
+      EditVerbose("Edit: terminating line: %s (Done)\n",ip->name);
+      done = true;
+      }
+
+   if (strstr(ip->name,comm) == NULL)
+      {
+      CURRENTLINEPTR = ip->next;
+      ctr++;
+      continue;
+      }
+
+   EditVerbose("Edit: uncomment line %s\n",ip->name);
+   CURRENTLINEPTR = ip->next;
+
+   if ((sp = malloc(strlen(ip->name)+2)) == NULL)
+      {
+      printf("cfengine: couldn't allocate memory in UnCommentNLines\n");
+      perror("malloc");
+      return false;
+      }
+
+   spc = sp;
+   
+   for (sp1 = ip->name; isspace(*sp1); sp1++)
+      {
+      *spc++ = *sp1;
+      }
+
+   *spc = '\0';
+
+   sp2 = ip->name+strlen(ip->name);
+
+   if ((strlen(end) != 0) && (strstr(ip->name,end) != NULL))
+      {
+      for (sp2 = ip->name+strlen(ip->name); strncmp(sp2,end,strlen(end)) != 0; sp2--)
+	 {
+	 }
+
+      *sp2 = '\0';
+      }
+
+   strcat(sp,sp1+strlen(comm));
+
+   if (sp2 != ip->name+strlen(ip->name))
+      {
+      strcat(sp,sp2+strlen(end));
+      }
+
+   ctr++;
+
+   if (strcmp(sp,ip->name) != 0)
+      {
+      NUMBEROFEDITS++;
+      }
+   
+   free(ip->name);
+   ip->name = sp;
+
+   if (done)
+      {
+      break;
+      }
+   }
+
+if (ctr-1 < N)
+   {
+   if (!SILENT)
+      {
+      printf("cfengine: CommentNLines commented only %d lines (not %d)\n",ctr-1,N);
+      }
+   }
+
+return true;
+}
 
 /********************************************************************/
 
@@ -1538,8 +1669,8 @@ char *item, *regex;
 { char fastmap[(1 << BYTEWIDTH)];
   struct re_pattern_buffer buf;
   struct re_registers regs;
-  int match, linefound = false, done;
-  char *sp, *err;
+  int match;
+  char *err;
 
 Debug2("ItemMatchesRegEx(%s %s)\n",item,regex);
 
