@@ -104,6 +104,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
    (*linkfiles)(pcwdfrom,pcwdto,inclusions,exclusions,copy);
    }
 
+closedir(dirh);
 return true;
 }
 
@@ -154,7 +155,7 @@ for (sp = path+strlen(path); sp != path-1; sp--)
    {
    if (*(sp-1) == '/')
       {
-      relpath[0] = NULL;
+      relpath[0] = '\0';
       sscanf(sp,"%[^/]%s", lastlink,relpath);
 
       if (MatchAFileSystem(server,lastlink))
@@ -398,7 +399,7 @@ LinkFiles(from,to,inclusions,exclusions,copy)  /* should return true if 'to' fou
 char *from, *to;
 struct Item *inclusions, *exclusions, *copy;
 
-{ struct stat buf,exbuf;
+{ struct stat buf;
   char linkbuf[bufsize], saved[bufsize], absto[bufsize], *sp, *lastnode;
   struct UidList fakeuid;
   struct Image ip;
@@ -436,7 +437,9 @@ if (IsWildItemIn(VCOPYLINKS,lastnode) || IsWildItemIn(copy,lastnode))
    ip.type = 't';
    ip.backup = true;
    ip.exclusions = NULL;
+   ip.inclusions = NULL;
    ip.symlink = NULL;
+   ip.classes = NULL;  /* if we get this far don't need to check again */
    Verbose("cfengine: link item %s marked for copying instead\n",from);
    CheckImage(to,from,&ip);
    return;
@@ -484,7 +487,7 @@ if (lstat(from,&buf) == 0)
          return true;
          }
 
-      saved[0] = NULL;
+      saved[0] = '\0';
       strcpy(saved,from);
       strcat(saved,CF_SAVED);
 
@@ -503,7 +506,7 @@ if (lstat(from,&buf) == 0)
 
 for (sp = linkbuf; sp < linkbuf+bufsize; sp++)      /* clear buff, readlink(2) */
    {
-   *sp = NULL;
+   *sp = '\0';
    }
 
 if (readlink(from,linkbuf,bufsize) == -1)
@@ -600,7 +603,7 @@ while (*commonto == *commonfrom)
    commonfrom++;
    }
 
-for (sp = commonfrom; *sp != NULL; sp++)
+for (sp = commonfrom; *sp != '\0'; sp++)
    {
    if (*sp == '/')
        {
@@ -641,7 +644,7 @@ char *from, *to;
 struct Item *inclusions,*exclusions,*copy;
 /* global LINKTO */
 
-{ char *sp, absto[bufsize], *lastnode;
+{ char absto[bufsize];
   char expand[bufsize];
   
 Debug2("AbsoluteLink(%s,%s)\n",from,to);
@@ -713,7 +716,7 @@ char *name;
 
 for (i = 0; i < bufsize; i++)
    {
-   linkbuf[i] = linkpath[i] = NULL;
+   linkbuf[i] = linkpath[i] = '\0';
    }
 
 if (readlink(name,linkbuf,bufsize) == -1)
@@ -728,7 +731,7 @@ if (linkbuf[0] != '/')
 
    for (sp = linkpath+strlen(linkpath); (*sp != '/') && (sp >= linkpath); sp-- )
      {
-     *sp = NULL;
+     *sp = '\0';
      }
    }
 
@@ -762,7 +765,7 @@ char *from, *to;
 struct Item *inclusions,*exclusions,*copy;
 
 { struct stat frombuf,tobuf;
-  char linkbuf[bufsize], saved[bufsize], *sp, *lastnode;
+  char saved[bufsize], *lastnode;
   struct UidList fakeuid;
   struct Image ip;
   
@@ -858,7 +861,7 @@ if (ENFORCELINKS)
       return true;
       }
 
-   saved[0] = NULL;
+   saved[0] = '\0';
    strcpy(saved,from);
    strcat(saved,CF_SAVED);
 
