@@ -125,7 +125,7 @@ strcpy (node,file);
 
 buffer[0] = '\0';
 
-for (sp = node; *sp != NULL; sp++)
+for (sp = node; *sp != '\0'; sp++)
    {
    if (*sp == '/')
       {
@@ -160,6 +160,7 @@ IMAGEBACKUP = false;
 if (CopyReg(file,buffer,sstat,dstat))
    {
    IMAGEBACKUP = imagecopy;
+   Verbose("cfengine: backed up to repository %s\n",buffer);
    return true;
    }
 else
@@ -179,6 +180,19 @@ char *str;
 str[strlen(str)-1] = '\0';
 }
 
+
+/*********************************************************************/
+
+Banner(string)
+
+char *string;
+
+{
+Verbose("---------------------------------------------------------------------\n");
+Verbose("%s\n",string);
+Verbose("---------------------------------------------------------------------\n\n");
+}
+
 /*********************************************************************/
 /* TOOLIT : Locks and Signals                                        */
 /*********************************************************************/
@@ -279,12 +293,12 @@ char *str;
 
 ACTION = none;
 
-for (sp = str; *sp != NULL; sp++)
+for (sp = str; *sp != '\0'; sp++)
    {
    *sp = ToLower(*sp);
    }
 
-for (i = 1; ACTIONID[i] != NULL; i++)
+for (i = 1; ACTIONID[i] != '\0'; i++)
    {
    if (strcmp(ACTIONID[i],str) == 0)
       {
