@@ -34,7 +34,7 @@
 MountPathDefined()
 
 {
-if (VMOUNTPATH[0] == NULL)
+if (VMOUNTPATH[0] == '\0')
    {
    printf("cfengine: Program does not define where the host's file systems will be mounted\n");
    printf("          mountpattern undefined\n");
@@ -51,7 +51,7 @@ MatchAFileSystem(server, lastlink)
 
 char *server, *lastlink;
 
-{ struct Item *mp,*ip;
+{ struct Item *mp;
   char *sp;
   char host[maxvarsize];
 
