@@ -359,7 +359,7 @@ else
       case misc_mounts: if (MOUNT_FROM && MOUNT_ONTO && (strcmp(item,"rw") == 0 || strcmp(item,"ro") == 0))
                            {
                            AppendMiscMount(MOUNTFROM,MOUNTONTO,item);
-                           CURRENTITEM[0] = NULL;
+                           CURRENTITEM[0] = '\0';
                            MOUNT_FROM = false;
                            MOUNT_ONTO = false;
                            }
@@ -1057,13 +1057,13 @@ char *item;
 
 { char value[maxvarsize];
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(VBUFF,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("File attribute with no value");
    }
@@ -1098,13 +1098,13 @@ char *item;
 
 { char value[maxvarsize];
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(VBUFF,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("Image attribute with no value");
    }
@@ -1151,13 +1151,13 @@ char *item;
 
 { char value[maxvarsize];
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(VBUFF,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("Tidy attribute with no value");
    }
@@ -1188,6 +1188,10 @@ switch(GetCommAttribute(item))
    case cftype:    HandleTidyType(value);
                    break;
 
+   case cfdirlinks:
+                   HandleTidyLinkDirs(value);
+		   break;
+
    default:        yyerror("Illegal tidy attribute");
    }
 }
@@ -1200,13 +1204,13 @@ char *item;
 
 { char value[maxvarsize];
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(item,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("Directory attribute with no value");
    }
@@ -1234,13 +1238,13 @@ char *item;
 
 { char value[maxvarsize];
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(VBUFF,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("Disable attribute with no value");
    }
@@ -1268,13 +1272,13 @@ char *item;
 
 { char value[maxvarsize];
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(VBUFF,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("Link attribute with no value");
    }
@@ -1314,13 +1318,13 @@ if (HAVE_RESTART)     /* wrote `restart' without followingby ".." */
    yyerror("Missing restart command (quoted string expected) or bad SetOptionString placement");
    }
 
-VBUFF[0] = value[0] = NULL;
+VBUFF[0] = value[0] = '\0';
 
 ExpandVarstring(item,VBUFF,NULL);
 
 sscanf(VBUFF,"%*[^=]=%s",value);
 
-if (value[0] == NULL)
+if (value[0] == '\0')
    {
    yyerror("Process attribute with no value");
    }
@@ -1420,8 +1424,7 @@ InstallDefaultRouteItem(item)
 
 char *item;
 
-{ struct sockaddr_in *sin;
-  struct hostent *hp;
+{ struct hostent *hp;
   struct in_addr inaddr;
 
 Debug1("Install defaultroute mode (%s)\n",item);
@@ -1553,7 +1556,7 @@ HandleHomePattern(pattern)
 char *pattern;
 
 {
-VBUFF[0]=NULL;
+VBUFF[0]='\0';
 ExpandVarstring(pattern,VBUFF,"");
 AppendItem(&VHOMEPATLIST,VBUFF,NULL);
 }
@@ -1648,7 +1651,7 @@ if ( ! IsInstallable(CLASSBUFF))
    return;
    }
 
-if (VMAILSERVER[0] != NULL)
+if (VMAILSERVER[0] != '\0')
    {
    FatalError("Redefinition of mailserver");
    }
@@ -1673,7 +1676,7 @@ if ( ! IsInstallable(CLASSBUFF))
    return;
    }
 
-VBUFF[0]=NULL;
+VBUFF[0]='\0';
 ExpandVarstring(item,VBUFF,"");
 
 if (VBUFF[0] != '/')
@@ -1782,7 +1785,7 @@ if ( ! IsInstallable(CLASSBUFF))
    return;
    }
 
-VBUFF[0]=NULL;                                /* Expand any variables */
+VBUFF[0]='\0';                                /* Expand any variables */
 ExpandVarstring(from,VBUFF,"");
 
 Build2DListFromVarstring(&tp,to,'/');
@@ -1864,7 +1867,7 @@ if ( ! IsInstallable(CLASSBUFF))
    return;
    }
 
-VBUFF[0] = NULL;
+VBUFF[0] = '\0';
 ExpandVarstring(path,VBUFF,"");
 
 AppendItem(&VREQUIRED,VBUFF,CLASSBUFF);
@@ -2031,7 +2034,7 @@ switch (action)
                      return;
                      }
                   InstallTidyItem(CURRENTPATH,CURRENTITEM,VRECURSE,VAGE,(char)PTRAVLINKS,
-				  TIDYSIZE,AGETYPE,CLASSBUFF);
+				  TIDYSIZE,AGETYPE,LINKDIRS,CLASSBUFF);
                   break;
 
    case makepath: InstallMakePath(CURRENTPATH,PLUSMASK,MINUSMASK,VUIDNAME,VGIDNAME);
@@ -2042,7 +2045,7 @@ switch (action)
 
    case links:
 
-                  if (LINKTO[0] == NULL)
+                  if (LINKTO[0] == '\0')
                      {
                      return;
                      }
@@ -2065,8 +2068,8 @@ switch (action)
                   break;
    }
 
-LINKFROM[0] = NULL;
-LINKTO[0] = NULL;
+LINKFROM[0] = '\0';
+LINKTO[0] = '\0';
 ACTIONPENDING = false;
 CURRENTITEM[0] = '\0';
 CURRENTITEM[0] = '\0';
@@ -2079,12 +2082,12 @@ Debug1("   END InstallPending]\n\n");
 /* Level 3                                                         */
 /*******************************************************************/
 
-InstallTidyItem (path,wild,rec,age,travlinks,tidysize,type,classes)
+InstallTidyItem (path,wild,rec,age,travlinks,tidysize,type,ldirs,classes)
 
 char *wild, *path;
 short age,tidysize;
 int rec, travlinks;
-char type, *classes;
+char type, ldirs, *classes;
 
 { struct TwoDimList *tp = NULL;
   char *sp;
@@ -2097,11 +2100,11 @@ for (sp = Get2DListEnt(tp); sp != NULL; sp = Get2DListEnt(tp))
    {
    if (TidyPathExists(path))
       {
-      AddTidyItem(sp,wild,rec,age,travlinks,tidysize,type,classes);
+      AddTidyItem(sp,wild,rec,age,travlinks,tidysize,type,ldirs,classes);
       }
    else
       {
-      InstallTidyPath(sp,wild,rec,age,travlinks,tidysize,type,classes);
+      InstallTidyPath(sp,wild,rec,age,travlinks,tidysize,type,ldirs,classes);
       }
    }
 
@@ -2136,7 +2139,7 @@ if (strlen(type) > 0 && strcmp(type,"plain") != 0 && strcmp(type,"file") !=0 &&
 
 for (i=0; i<bufsize; i++)
    {
-   buf[i] = VBUFF[i] = NULL;
+   buf[i] = VBUFF[i] = '\0';
    }
 
 ExpandVarstring(path,buf,"");
@@ -2203,7 +2206,6 @@ char *gidnames;
 
 { struct File *ptr;
   char *sp, *spe;
-  int i;
 
 Debug1("InstallMakePath (%s) (+%o)(-%o)(%s)(%s)\n",path,plus,minus,uidnames,gidnames);
 
@@ -2213,7 +2215,7 @@ if ( ! IsInstallable(CLASSBUFF))
    return;
    }
 
-VBUFF[0]=NULL;                                /* Expand any variables */
+VBUFF[0]='\0';                                /* Expand any variables */
 ExpandVarstring(path,VBUFF,"");
 
 if ((ptr = (struct File *)malloc(sizeof(struct File))) == NULL)
@@ -2350,6 +2352,28 @@ yyerror("Illegal age search type, must be atime/ctime/mtime");
 
 /*******************************************************************/
 
+HandleTidyLinkDirs(value)
+
+char *value;
+
+{
+if (strcmp(value,"keep")== 0)
+   {
+   LINKDIRS = 'k';
+   return;
+   }
+
+if (strcmp(value,"tidy")== 0 || strcmp(value,"delete") == 0)
+   {
+   LINKDIRS = 't';
+   return;
+   }
+
+yyerror("Illegal linkdirs value, must be keep/delete/tidy");
+}
+
+/*******************************************************************/
+
 HandleForceCopy(value)
 
 char *value;
@@ -2400,7 +2424,7 @@ char *action;
 
 { int i;
 
-for (i = 0; FILEACTIONTEXT[i] != NULL; i++)
+for (i = 0; FILEACTIONTEXT[i] != '\0'; i++)
    {
    if (strcmp(action,FILEACTIONTEXT[i]) == 0)
       {
@@ -2427,7 +2451,6 @@ char travlinks;
 
 { struct File *ptr;
   char *sp, *spe, *spl;
-  int i;
   struct TwoDimList *tp = NULL;
 
 Debug1("InstallFileaction (%s) (+%o)(-%o) (%s) (%d) (%c)\n",path,plus,minus,FILEACTIONTEXT[action],action,travlinks);
@@ -2501,7 +2524,6 @@ char action, comp;
 { struct Process *ptr;
   char *sp1, *sp2, *spe;
   char buf1[bufsize], buf2[bufsize];
-  int i;
 
 if (comp == 't')
    {
@@ -2726,18 +2748,18 @@ char *s;
 { int i;
   char comm[maxvarsize];
 
-for (i = 0; s[i] != NULL; i++)
+for (i = 0; s[i] != '\0'; i++)
    {
    s[i] = ToLower(s[i]);
    }
 
-comm[0]=NULL;
+comm[0]='\0';
 
 sscanf(s,"%[^=]",comm);
 
 Debug1("GetCommAttribute(%s)\n",comm);
 
-for (i = 0; COMMATTRIBUTES[i] != NULL; i++)
+for (i = 0; COMMATTRIBUTES[i] != '\0'; i++)
    {
    if (strncmp(COMMATTRIBUTES[i],comm,strlen(comm)) == 0)
       {
@@ -2908,7 +2930,7 @@ char *value;
 
 for (i = 1; SIGNALS[i] != 0; i++)
    {
-   for (sp = value; *sp != NULL; sp++)
+   for (sp = value; *sp != '\0'; sp++)
       {
       *sp = ToUpper(*sp);
       }
@@ -2938,9 +2960,8 @@ AppendToActionSequence (action)
 
 char *action;
 
-{ int i,j = 0;
+{ int j = 0;
   char *sp,cbuff[bufsize],actiontxt[bufsize];
-  struct Item *ip;
 
 Debug1("Installing item (%s) in the action sequence list\n",action);
 
@@ -2950,12 +2971,12 @@ cbuff[0]='\0';
 actiontxt[0]='\0';
 sp = action;
 
-while (*sp != NULL)
+while (*sp != '\0')
    {
    ++j;
    sscanf(sp,"%[^.]",cbuff);
 
-   while ((*sp != NULL) && (*sp !='.'))
+   while ((*sp != '\0') && (*sp !='.'))
       {
       sp++;
       }
@@ -3167,7 +3188,7 @@ char *uidnames;
 
 uidlist = NULL;
 
-for (sp = uidnames; *sp != NULL; sp+=strlen(uidbuff))
+for (sp = uidnames; *sp != '\0'; sp+=strlen(uidbuff))
    {
    if (*sp == ',')
       {
@@ -3266,7 +3287,7 @@ char *gidnames;
 
 gidlist = NULL;
 
-for (sp = gidnames; *sp != NULL; sp+=strlen(gidbuff))
+for (sp = gidnames; *sp != '\0'; sp+=strlen(gidbuff))
    {
    if (*sp == ',')
       {
@@ -3315,7 +3336,7 @@ char *comm, arg[maxshellargs][bufsize];
   int i = 0, j;
   char buff[bufsize];
 
-for (sp = comm; *sp != NULL; sp++)
+for (sp = comm; *sp != '\0'; sp++)
    {
    bzero(buff,bufsize);
 
@@ -3429,15 +3450,16 @@ MINUSMASK = 0;
 VRECURSE = 0;
 VAGE = 99999;
 VUIDNAME[0] = '*';
-VUIDNAME[1] = NULL;
+VUIDNAME[1] = '\0';
 VGIDNAME[0] = '*';
-VGIDNAME[1] = NULL;
+VGIDNAME[1] = '\0';
 HAVE_RESTART = 0;
 FILEACTION=warnall;
-CURRENTPATH[0] = NULL;
+CURRENTPATH[0] = '\0';
+CURRENTITEM[0] = '\0';
 ACTIONPENDING = false;
-DESTINATION[0] = NULL;
-IMAGEACTION[0] = NULL;
+DESTINATION[0] = '\0';
+IMAGEACTION[0] = '\0';
 PTRAVLINKS = (short) '?';
 FORCECOPY = false;
 IMAGEBACKUP = true;
@@ -3446,16 +3468,17 @@ TIDYSIZE=0;
 PROMATCHES=-1;
 AGETYPE='a';
 COPYTYPE = 't';
-VEXCLUDEPARSE = NULL;
-VINCLUDEPARSE = NULL;
-VCPLNPARSE = NULL;
+LINKDIRS = 'k';
+VEXCLUDEPARSE = '\0';
+VINCLUDEPARSE = '\0';
+VCPLNPARSE = '\0';
 
  /* Make sure we don't clean the buffer in the middle of a link! */
 
 if ( ! ACTION_IS_LINK && ! ACTION_IS_LINKCHILDREN)
    {
-   LINKFROM[0] = NULL;
-   LINKTO[0] = NULL;
+   LINKFROM[0] = '\0';
+   LINKTO[0] = '\0';
    LINKSILENT = false;
    LINKTYPE = 's';
    }
@@ -3468,7 +3491,7 @@ SetMountPath (value)
 char *value;
 
 {
-if (VMOUNTPATH[0] != NULL)
+if (VMOUNTPATH[0] != '\0')
    {
    yyerror("Redefinition of system variable mountpath");
    }
@@ -3488,7 +3511,7 @@ if (*value != '/')
    yyerror("File repository must be an absolute directory name");
    }
 
-if (VREPOSITORY[0] != NULL)
+if (VREPOSITORY[0] != '\0')
    {
    yyerror("Redefinition of system variable repository");
    }
